@@ -1,15 +1,16 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """`Utilities to interact with the application`."""
 
 import os
-from typing import List, Iterable
+from typing import List, Iterable, Callable, BinaryIO
+from PyQt5.QtGui import QPixmap
 
-from vimiv.utils import files
+from vimiv.utils import files, imagereader
 
 from vimiv.api import (
     commands,
@@ -50,7 +51,7 @@ def pathlist(mode: modes.Mode = None) -> List[str]:
         The list of currently open paths.
     """
     mode = mode if mode else modes.current()
-    return mode.pathlist
+    return list(mode.pathlist)  # Ensure we create a copy
 
 
 @keybindings.register("o", "command --text='open '")
@@ -76,3 +77,19 @@ def open_paths(paths: Iterable[str]) -> None:
         modes.LIBRARY.enter()
     else:
         raise commands.CommandError("No valid paths")
+
+
+def add_external_format(
+    file_format: str,
+    test_func: Callable[[bytes, BinaryIO], bool],
+    load_func: Callable[[str], QPixmap],
+) -> None:
+    """Add support for new fileformat.
+
+    Args:
+        file_format: String value of the file type
+        test_func: Function returning True if load_func supports this type.
+        load_func: Function to load a QPixmap from the passed path.
+    """
+    files.add_image_format(file_format, test_func)
+    imagereader.external_handler[file_format] = load_func
