@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Mark and tag images."""
@@ -27,8 +27,10 @@ class Mark(QObject):
     Signals:
         marked: Emitted with the image path when an image was marked.
         unmarked: Emitted with the image path when an image was unmarked.
+        markdone: Emitted when all image of a given paths list are (un)marked.
 
     Attributes:
+        _indicator: Attribute to cache the evaluated mark indicator string.
         _marked: List of all currently marked images.
         _last_marked: List of images that were marked before clearing.
         _watcher: QFileSystemWatcher to monitor marked paths.
@@ -36,10 +38,12 @@ class Mark(QObject):
 
     marked = pyqtSignal(str)
     unmarked = pyqtSignal(str)
+    markdone = pyqtSignal()
 
     @objreg.register
     def __init__(self) -> None:
         super().__init__()
+        self._indicator: Optional[str] = None
         self._marked: List[str] = []
         self._last_marked: List[str] = []
         self._watcher: Optional[QFileSystemWatcher] = None
@@ -79,6 +83,7 @@ class Mark(QObject):
         for path in paths:
             if files.is_image(path):
                 self._toggle_mark(path)
+        self.markdone.emit()
 
     @commands.register()
     def mark_clear(self) -> None:
@@ -96,6 +101,7 @@ class Mark(QObject):
         for path in self._last_marked:
             self.unmarked.emit(path)
             _logger.debug("Unmarked '%s'", path)
+        self.markdone.emit()
 
     @commands.register()
     def mark_restore(self) -> None:
@@ -106,6 +112,7 @@ class Mark(QObject):
         for path in self._marked:
             self.marked.emit(path)
             _logger.debug("Marked '%s'", path)
+        self.markdone.emit()
 
     @commands.register()
     def tag_write(self, name: str) -> None:
@@ -177,6 +184,7 @@ class Mark(QObject):
         for path in paths:
             self.marked.emit(path)
             _logger.debug("Marked '%s'", path)
+        self.markdone.emit()
 
     @commands.register()
     def tag_open(self, name: str) -> None:
@@ -198,7 +206,7 @@ class Mark(QObject):
     def mark_indicator(self) -> str:
         """Indicator if the current image is marked."""
         if modes.current().current_path in self._marked:
-            return Mark.indicator()
+            return self.indicator
         return ""
 
     @status.module("{mark-count}")
@@ -214,22 +222,23 @@ class Mark(QObject):
         """Return list of currently marked paths."""
         return self._marked
 
-    @staticmethod
-    def indicator() -> str:
+    @property
+    def indicator(self) -> str:
         """Colored mark indicator."""
-        color = styles.get("mark.color")
-        return wrap_style_span(
-            f"color: {color}", settings.statusbar.mark_indicator.value
-        )
+        if self._indicator is None:
+            color = styles.get("mark.color")
+            self._indicator = wrap_style_span(
+                f"color: {color}", settings.statusbar.mark_indicator.value
+            )
+        return self._indicator
 
-    @staticmethod
-    def highlight(text: str, marked: bool = True) -> str:
+    def highlight(self, text: str, marked: bool = True) -> str:
         """Add/remove mark indicator from text.
 
         If marked is True, then the indicator is added to the left of the text.
         Otherwise it is removed.
         """
-        mark_str = Mark.indicator() + " "
+        mark_str = self.indicator + " "
         text = remove_prefix(text, mark_str)
         return mark_str + text if marked else text
 
