@@ -1,13 +1,13 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """`Command storage and initialization`.
 
 The user interacts with vimiv using commands. Creating a new command is done
-using the :func:`register` decorator. The command name is directly infered from
+using the :func:`register` decorator. The command name is directly inferred from
 the function name, the functions docstring is used to document the command. The
 arguments supported by the command are also deduced by inspecting the arguments
 the function takes. To understand these concepts, lets add a simple command
