@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """`Utilities to map commands to a sequence of keys`.
@@ -156,3 +156,9 @@ def items() -> Iterator[Tuple[modes.Mode, Iterable[Tuple[str, str]]]]:
             yield mode, sort(set(get(mode)) - global_bindings)
         else:
             yield mode, sort(get(mode))
+
+
+def check() -> None:
+    """Checks every mode for keybinding clashes and logs warnings."""
+    for _, bindings_trie in _registry.items():
+        bindings_trie.check()
