@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """`Default modes and utility functions for mode handling`.
@@ -123,7 +123,7 @@ class Mode(QObject, metaclass=AbstractQObjectMeta):
 
         If the mode is currently visible, close it. Otherwise enter it.
         """
-        if self.widget.isVisible():
+        if self.widget is not None and self.widget.isVisible():
             self.close()
         else:
             self.enter()
