@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """*Utilities to add status modules and retrieve status text*.
@@ -25,7 +25,7 @@ by the text "user: " we run::
 
     updated_text = status.evaluate("user: {username}")
 
-The occurance of '{username}' is then replaced by the outcome of the username()
+The occurrence of '{username}' is then replaced by the outcome of the username()
 function defined earlier.
 
 If any other object requires the status to be updated, they should call
@@ -69,7 +69,7 @@ def module(name: str) -> Callable[[ModuleFunc], ModuleFunc]:
     """Decorator to register a function as status module.
 
     The decorated function must return a string that can be displayed as
-    status. When calling :func:`evaluate`, any occurance of ``name`` will be
+    status. When calling :func:`evaluate`, any occurrence of ``name`` will be
     replaced by the return value of the decorated function.
 
     Args:
@@ -93,7 +93,7 @@ def module(name: str) -> Callable[[ModuleFunc], ModuleFunc]:
 def evaluate(text: str) -> str:
     """Evaluate the status modules and update text accordingly.
 
-    Replaces all occurances of module names with the output of the
+    Replaces all occurrences of module names with the output of the
     corresponding function.
 
     Example:
