@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 r"""Handler to take care of the current working directory.
@@ -17,7 +17,7 @@ In addition the directory and current image is monitored using QFileSystemWatche
 changes are exposed via three signals:
 
 * ``loaded`` when the working directory has changed and the content was loaded
-* ``changed`` when the content of the current directory has chagned
+* ``changed`` when the content of the current directory has changed
 * ``images_changed`` when the images in the current directory where changed
 
 The first two signals are emitted with the list of images and list of directories in the
