@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Classes and functions to run commands.
@@ -67,7 +67,7 @@ def run(text: str, mode: api.modes.Mode, count: str = "") -> None:
     _logger.debug("Running '%s'", text)
 
     def update_part(text: str) -> str:
-        """Update aliases and % in final parts without seperator."""
+        """Update aliases and % in final parts without separator."""
         if SEPARATOR in text:
             return text
         return wildcards.expand_internal(alias(text.strip(), mode), mode)
