@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Various completion models for command line completion."""
@@ -13,7 +13,7 @@ from typing import List, Set, Tuple
 
 from vimiv import api
 from vimiv.commands import aliases
-from vimiv.utils import files, trash_manager, escape_ws, unescape_ws
+from vimiv.utils import files, trash_manager
 
 
 class CommandModel(api.completion.BaseModel):
@@ -59,7 +59,11 @@ class ExternalCommandModel(api.completion.BaseModel):
         if self._initialized:
             return
         executables = self._get_executables()
-        self.set_data((f":!{cmd}",) for cmd in executables if not cmd.startswith("."))
+        self.set_data(
+            (f":!{api.completion.escape(cmd)}",)
+            for cmd in executables
+            if not cmd.startswith(".")
+        )
         self._initialized = True
 
     def _get_executables(self) -> List[str]:
@@ -116,7 +120,7 @@ class PathModel(api.completion.BaseModel):
         )
 
     def _create_row(self, path):
-        return (f":{self._command} {escape_ws(path)}",)
+        return (f":{self._command} {api.completion.escape(path)}",)
 
     def _get_directory(self, text: str) -> str:
         """Retrieve directory for which the path completion is created."""
@@ -125,8 +129,10 @@ class PathModel(api.completion.BaseModel):
             return "."
         _prefix, directory = match.groups()
         if "/" not in directory:
-            return unescape_ws(directory) if os.path.isdir(directory) else "."
-        return unescape_ws(os.path.dirname(directory))
+            if os.path.isdir(directory):
+                return api.completion.unescape(directory)
+            return "."
+        return api.completion.unescape(os.path.dirname(directory))
 
 
 class SettingsModel(api.completion.BaseModel):
@@ -184,23 +190,28 @@ class TrashModel(api.completion.BaseModel):
             column_widths=(0.4, 0.45, 0.15),
             valid_modes=api.modes.GLOBALS,
         )
+        self._old_date_re = re.compile(r"(\d{4})(\d{2})(\d{2})T(\d{2})(\d{2})(\d{2})")
+        self._date_re = re.compile(r"(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})")
 
     def on_enter(self, text: str) -> None:
         """Update trash model on enter to include any newly un-/deleted paths."""
         data = []
         for path in files.listdir(trash_manager.files_directory()):
-            cmd = f":undelete {os.path.basename(path)}"
+            cmd = f":undelete {api.completion.escape(os.path.basename(path))}"
             # Get info and format it neatly
             original, date = trash_manager.trash_info(path)
             original = original.replace(os.path.expanduser("~"), "~")
             original = os.path.dirname(original)
-            date = "%s-%s-%s %s:%s" % (
-                date[2:4],
-                date[4:6],
-                date[6:8],
-                date[9:11],
-                date[11:13],
-            )
+            date_match = self._date_re.match(date)
+            if date_match is None:
+                # Wrong date formatting that was used up to v0.7.0
+                # TODO remove after releasing v1.0.0
+                date_match = self._old_date_re.match(date)
+            if date_match is not None:
+                year, month, day, hour, minute, _ = date_match.groups()
+                date = f"{year}-{month}-{day} {hour}:{minute}"
+            else:
+                date = "date unknown"
             # Append data in column form
             data.append((cmd, original, date))
         self.set_data(data)
@@ -222,7 +233,8 @@ class TagModel(api.completion.BaseModel):
     def on_enter(self, text: str) -> None:
         """Update tag model on enter to include any new/deleted tags."""
         self.set_data(
-            (f":{self._command} {fname}",) for fname in files.listfiles(api.mark.tagdir)
+            (f":{self._command} {api.completion.escape(fname)}",)
+            for fname in files.listfiles(api.mark.tagdir)
         )
 
 
