@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Commands dealing with settings and configuration."""
@@ -71,6 +71,7 @@ def bind(keybinding: str, command: List[str], mode: str = None):
     """
     modeobj = api.modes.get_by_name(mode) if mode else api.modes.current()
     api.keybindings.bind(keybinding, " ".join(command), modeobj)
+    api.keybindings.check()
 
 
 @api.commands.register()
@@ -95,6 +96,5 @@ def unbind(keybinding: str, mode: str = None):
 def nop():
     """Do nothing.
 
-    This is useful to remove default keybindings by explicitly binding them to
-    nop.
+    This is useful to remove keys bound by Qt by explicitly binding them to nop.
     """
