@@ -1,12 +1,13 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Methods to read keybindings from file and store them."""
 
 import configparser
+from typing import Iterable, Tuple
 
 from vimiv import api, config
 from vimiv.utils import log
@@ -14,10 +15,13 @@ from vimiv.utils import log
 
 _logger = log.module_logger(__name__)
 
+DEL_BINDING_COMMAND = "unbind"
+
 
 def parse(cli_path: str):
     """Parse keybindings from the keys.conf into the keybindings registry."""
     config.parse_config(cli_path, "keys.conf", read, dump)
+    api.keybindings.check()
 
 
 def dump(path: str):
@@ -47,19 +51,37 @@ def read(path: str) -> None:
         try:
             _logger.debug("Reading keybindings from section '%s'", section)
             mode = api.modes.get_by_name(section)
-            for keybinding, command in parser[section].items():
-                api.keybindings.bind(keybinding, command, mode)
-                _logger.debug(
-                    "Read keybinding '%s': '%s' for mode '%s'",
-                    keybinding,
-                    command,
-                    mode.name,
-                )
+            _read_mode(bindings=parser[section].items(), mode=mode)
         except api.modes.InvalidMode:
             _logger.warning("Ignoring bindings for unknown '%s' mode", section)
     _logger.debug("Read keybindings from '%s'", path)
 
 
+def _read_mode(bindings: Iterable[Tuple[str, str]], mode: api.modes.Mode):
+    """Read bindings for one mode into the keybindings registry."""
+    for keybinding, command in bindings:
+        if command == DEL_BINDING_COMMAND:
+            _delete_binding(keybinding, mode)
+        else:
+            api.keybindings.bind(keybinding, command, mode)
+            _logger.debug(
+                "Read keybinding '%s': '%s' for mode '%s'",
+                keybinding,
+                command,
+                mode.name,
+            )
+
+
+def _delete_binding(keybinding: str, mode: api.modes.Mode):
+    """Remove a keybinding for this specific mode."""
+    try:
+        api.keybindings.unbind(keybinding, mode)
+    except api.commands.CommandError:
+        _logger.warning(
+            "Cannot unbind '%s' for mode '%s', no binding found.", keybinding, mode.name
+        )
+
+
 class KeyfileParser(configparser.ConfigParser):
     """Parser used for keyfiles.
 
