@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Completion widget in the bar."""
@@ -63,10 +63,10 @@ class CompletionView(widgets.FlatTreeView):
         optional arguments:
             * ``--inverse``: Complete in inverse direction.
         """
-        try:
-            row = self.row() - 1 if inverse else self.row() + 1
-        except IndexError:  # First trigger of completion
+        if self.row() == -1:  # First trigger of completion
             row = -1 if inverse else 0
+        else:
+            row = self.row() - 1 if inverse else self.row() + 1
         # No suggestions
         if not self.model().rowCount():
             return
@@ -82,7 +82,7 @@ class CompletionView(widgets.FlatTreeView):
         self.update_column_widths()
 
     def update_column_widths(self):
-        """Resize columnds according to model."""
+        """Resize columns according to model."""
         for i in range(self.model().columnCount()):
             fraction = self.model().sourceModel().column_widths[i]
             self.setColumnWidth(i, int(fraction * self.width()))
