@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Handles key and mouse events."""
@@ -284,14 +284,18 @@ def _get_base_keysequence(event: QKeyEvent) -> SequenceT:
         Qt.Key_Home: "<home>",
         Qt.Key_End: "<end>",
     }
+    separator_keys = {
+        Qt.Key_Colon: "<colon>",
+        Qt.Key_Equal: "<equal>",
+    }
     if event.key() in special_keys:
         # Parse shift here as the key does not support it otherwise
         text = special_keys[event.key()]  # type: ignore
         if event.modifiers() & Qt.ShiftModifier:  # type: ignore
             return "<shift>", text
         return (text,)
-    if event.key() == Qt.Key_Colon:  # Required as : is the separator
-        return ("<colon>",)
+    if event.key() in separator_keys:  # Required as configparser crashes otherwise
+        return (separator_keys[event.key()],)  # type: ignore
     if event.text().isprintable():
         return (event.text(),)
     return (QKeySequence(event.key()).toString().lower(),)
