@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """QtWidgets for IMAGE mode."""
@@ -109,29 +109,29 @@ class ScrollableImage(eventhandler.EventHandlerMixin, QGraphicsView):
         """The currently visible part of the scene in the image coordinates."""
         return self.mapToScene(self.viewport().rect()).boundingRect() & self.sceneRect()
 
-    def _load_pixmap(self, pixmap: QPixmap, reload_only: bool) -> None:
+    def _load_pixmap(self, pixmap: QPixmap, keep_zoom: bool) -> None:
         """Load new pixmap into the graphics scene."""
         item = QGraphicsPixmapItem()
         item.setPixmap(pixmap)
         item.setTransformationMode(Qt.SmoothTransformation)
-        self._update_scene(item, item.boundingRect(), reload_only)
+        self._update_scene(item, item.boundingRect(), keep_zoom)
 
-    def _load_movie(self, movie: QMovie, reload_only: bool) -> None:
+    def _load_movie(self, movie: QMovie, keep_zoom: bool) -> None:
         """Load new movie into the graphics scene."""
         movie.jumpToFrame(0)
         if api.settings.image.autoplay.value:
             movie.start()
         widget = QLabel()
         widget.setMovie(movie)
-        self._update_scene(widget, QRectF(movie.currentPixmap().rect()), reload_only)
+        self._update_scene(widget, QRectF(movie.currentPixmap().rect()), keep_zoom)
 
-    def _load_svg(self, path: str, reload_only: bool) -> None:
+    def _load_svg(self, path: str, keep_zoom: bool) -> None:
         """Load new vector graphic into the graphics scene."""
         item = QtSvg.QGraphicsSvgItem(path)
-        self._update_scene(item, item.boundingRect(), reload_only)
+        self._update_scene(item, item.boundingRect(), keep_zoom)
 
     def _update_scene(
-        self, item: Union[QGraphicsItem, QLabel], rect: QRectF, reload_only: bool
+        self, item: Union[QGraphicsItem, QLabel], rect: QRectF, keep_zoom: bool
     ) -> None:
         """Update the scene with the newly loaded item."""
         self.scene().clear()
@@ -140,7 +140,7 @@ class ScrollableImage(eventhandler.EventHandlerMixin, QGraphicsView):
         else:
             self.scene().addWidget(item)
         self.scene().setSceneRect(rect)
-        self.scale(self._scale if reload_only else ImageScale.Overzoom)  # type: ignore
+        self.scale(self._scale if keep_zoom else ImageScale.Overzoom)  # type: ignore
         self._update_focalpoint()
 
     def _update_focalpoint(self):
@@ -218,7 +218,9 @@ class ScrollableImage(eventhandler.EventHandlerMixin, QGraphicsView):
         self._scale_to_float(self.zoom_level * scale)
         self._scale = ImageScaleFloat(self.zoom_level)
 
-    @api.keybindings.register("w", "scale --level=fit", mode=api.modes.IMAGE)
+    @api.keybindings.register(
+        ("w", "<equal>"), "scale --level=fit", mode=api.modes.IMAGE
+    )
     @api.keybindings.register("W", "scale --level=1", mode=api.modes.IMAGE)
     @api.keybindings.register("e", "scale --level=fit-width", mode=api.modes.IMAGE)
     @api.keybindings.register("E", "scale --level=fit-height", mode=api.modes.IMAGE)
@@ -310,7 +312,7 @@ class ScrollableImage(eventhandler.EventHandlerMixin, QGraphicsView):
     @api.keybindings.register("<space>", "play-or-pause", mode=api.modes.IMAGE)
     @api.commands.register(mode=api.modes.IMAGE)
     def play_or_pause(self):
-        """Toggle betwen play and pause of animation."""
+        """Toggle between play and pause of animation."""
         with contextlib.suppress(IndexError, AttributeError):  # No items, not a movie
             widget = self.items()[0].widget()
             movie = widget.movie()
