@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Library widget with model and delegate."""
@@ -133,7 +133,7 @@ class Library(eventhandler.EventHandlerMixin, widgets.FlatTreeView):
 
     @utils.slot
     def _on_closed(self):
-        """Hide library widget if library mode was clsed."""
+        """Hide library widget if library mode was closed."""
         self.hide()
         self._last_selected = ""
 
@@ -290,7 +290,8 @@ class Library(eventhandler.EventHandlerMixin, widgets.FlatTreeView):
     def store_position(self):
         """Set the stored position for a directory if possible."""
         with contextlib.suppress(IndexError):
-            self._positions[os.getcwd()] = Position(self.current(), self.row())
+            position = Position(self.current(), self.row())
+            self._positions[os.getcwd()] = position if position.row != -1 else None
 
     def load_directory(self):
         """Update library for new or reloaded directory."""
@@ -432,7 +433,7 @@ class LibraryModel(QStandardItemModel):
             are_directories: Whether all paths are directories.
         """
         get_size = files.get_size_directory if are_directories else files.get_size_file
-        mark_prefix = api.mark.indicator() + " "
+        mark_prefix = api.mark.indicator + " "
         for i, path in enumerate(paths, start=self.rowCount() + 1):
             name = os.path.basename(path)
             if are_directories:
@@ -473,6 +474,8 @@ class LibraryDelegate(QStyledItemDelegate):
         self.odd_bg = QColor(styles.get("library.odd.bg"))
         self.search_bg = QColor(styles.get("library.search.highlighted.bg"))
 
+        self.mark_str = api.mark.highlight("")
+
     def createEditor(self, *_):
         """Library is not editable by the user."""
         return None
@@ -577,13 +580,12 @@ class LibraryDelegate(QStyledItemDelegate):
         Returns:
             Elided version of the text.
         """
-        mark_str = api.mark.highlight("")
         html_stripped = strip_html(text)
         # Html only surrounds the leading mark indicator as directories are never marked
-        if text.startswith(mark_str):
-            mark_stripped = strip_html(mark_str)
+        if text.startswith(self.mark_str):
+            mark_stripped = strip_html(self.mark_str)
             elided = font_metrics.elidedText(html_stripped, Qt.ElideMiddle, width)
-            return elided.replace(mark_stripped, mark_str)
+            return elided.replace(mark_stripped, self.mark_str)
         # Html surrounds the full text as the file may be a directory which is displayed
         # in bold
         elided = font_metrics.elidedText(html_stripped, Qt.ElideMiddle, width)
