@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Thumbnail widget."""
@@ -87,7 +87,9 @@ class ThumbnailView(
         self.setResizeMode(QListWidget.Adjust)
 
         self.setItemDelegate(ThumbnailDelegate(self))
+        self.setDragEnabled(False)
 
+        api.signals.all_images_cleared.connect(self.clear)
         api.signals.new_image_opened.connect(self._select_path)
         api.signals.new_images_opened.connect(self._on_new_images_opened)
         api.settings.thumbnail.size.changed.connect(self._on_size_changed)
@@ -98,6 +100,7 @@ class ThumbnailView(
         self.doubleClicked.connect(self.open_selected)
         api.mark.marked.connect(self._mark_highlight)
         api.mark.unmarked.connect(lambda path: self._mark_highlight(path, marked=False))
+        api.mark.markdone.connect(self.repaint)
         synchronize.signals.new_library_path_selected.connect(self._select_path)
 
         styles.apply(self)
@@ -109,6 +112,11 @@ class ThumbnailView(
     def item(self, index: int) -> "ThumbnailItem":
         return cast(ThumbnailItem, super().item(index))
 
+    def clear(self):
+        """Override clear to also empty paths."""
+        self._paths = []
+        super().clear()
+
     @pyqtSlot(list)
     def _on_new_images_opened(self, paths: List[str]):
         """Load new paths into thumbnail widget.
@@ -188,7 +196,6 @@ class ThumbnailView(
             return
         item = self.item(index)
         item.marked = marked
-        self.repaint()
 
     @api.commands.register(mode=api.modes.THUMBNAIL)
     def open_selected(self):
