@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Classes to deal with the actual image file."""
@@ -15,7 +15,7 @@ from PyQt5.QtCore import QObject, QCoreApplication
 from PyQt5.QtGui import QPixmap, QImageReader, QMovie
 
 from vimiv import api, utils, imutils
-from vimiv.utils import files, log, asyncrun, lazy
+from vimiv.utils import files, log, asyncrun, lazy, imagereader
 
 QtSvg = lazy.import_module("PyQt5.QtSvg", optional=True)
 
@@ -50,10 +50,10 @@ class ImageFileHandler(QObject):
         QCoreApplication.instance().aboutToQuit.connect(self._on_quit)
 
     @utils.slot
-    def _on_new_image_opened(self, path: str):
+    def _on_new_image_opened(self, path: str, keep_zoom: bool):
         """Load proper displayable QWidget for a new image path."""
         self._maybe_write(self._path)
-        self._load(path, reload_only=False)
+        self._load(path, keep_zoom=keep_zoom)
 
     @utils.slot
     def _on_images_cleared(self):
@@ -65,7 +65,7 @@ class ImageFileHandler(QObject):
     @api.commands.register(mode=api.modes.IMAGE)
     def reload(self):
         """Reload the current image."""
-        self._load(self._path, reload_only=True)
+        self._load(self._path, keep_zoom=True)
 
     def _maybe_write(self, path, parallel=True):
         """Write image to disk if requested and it has changed.
@@ -88,45 +88,40 @@ class ImageFileHandler(QObject):
         """Possibly write changes to disk on quit."""
         self._maybe_write(self._path, parallel=False)
 
-    def _load(self, path: str, reload_only: bool):
+    def _load(self, path: str, keep_zoom: bool):
         """Load proper displayable QWidget for a path.
 
         This reads the image using QImageReader and then emits the appropriate
         *_loaded signal to tell the image to display a new object.
         """
-        # Pass file format explicitly as imghdr does a much better job at this than the
-        # file name based approach of QImageReader
-        file_format = files.imghdr.what(path)
-        if file_format is None:
-            log.error("%s is not a valid image", path)
-            return
-        reader = QImageReader(path, file_format.encode())
-        reader.setAutoTransform(True)  # Automatically apply exif orientation
-        if not reader.canRead():
-            log.error("Cannot read image %s", path)
+        try:
+            reader = imagereader.get_reader(path)
+        except ValueError as e:
+            log.error(str(e))
             return
         # SVG
-        if file_format == "svg" and QtSvg is not None:
+        if reader.is_vectorgraphic and QtSvg is not None:
             # Do not store image and only emit with the path as the
             # VectorGraphic widget needs the path in the constructor
-            api.signals.svg_loaded.emit(path, reload_only)
+            api.signals.svg_loaded.emit(path, keep_zoom)
             self._edit_handler.clear()
         # Gif
-        elif reader.supportsAnimation():
+        elif reader.is_animation:
             movie = QMovie(path)
             if not movie.isValid() or movie.frameCount() == 0:
                 log.error("Error reading animation %s: invalid data", path)
                 return
-            api.signals.movie_loaded.emit(movie, reload_only)
+            api.signals.movie_loaded.emit(movie, keep_zoom)
             self._edit_handler.clear()
         # Regular image
         else:
-            pixmap = QPixmap.fromImageReader(reader)
-            if reader.error():
-                log.error("Error reading image %s: %s", path, reader.errorString())
+            try:
+                pixmap = reader.get_pixmap()
+            except ValueError as e:
+                log.error("%s", e)
                 return
             self._edit_handler.pixmap = pixmap
-            api.signals.pixmap_loaded.emit(pixmap, reload_only)
+            api.signals.pixmap_loaded.emit(pixmap, keep_zoom)
         self._path = path
 
     @api.commands.register(mode=api.modes.IMAGE)
@@ -215,7 +210,10 @@ def _write(pixmap, path, original_path):
     os.close(handle)
     pixmap.save(filename)
     # Copy exif info from original file to new file
-    imutils.exif.copy_exif(original_path, filename)
+    try:
+        imutils.exif.ExifHandler(original_path).copy_exif(filename)
+    except imutils.exif.UnsupportedExifOperation:
+        pass
     shutil.move(filename, path)
     # Check if valid image was created
     if not os.path.isfile(path):
