@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Filelist of images.
@@ -19,7 +19,7 @@ from PyQt5.QtCore import QObject, pyqtSlot
 from vimiv import api, utils, imutils
 from vimiv.commands import search, number_for_command
 from vimiv.imutils import slideshow
-from vimiv.utils import log
+from vimiv.utils import files, log
 
 
 _paths: List[str] = []
@@ -28,26 +28,38 @@ _logger = log.module_logger(__name__)
 
 
 # We want to use the name next here as it is the best name for the command
+@api.keybindings.register("<ctrl>n", "next --keep-zoom", mode=api.modes.IMAGE)
 @api.keybindings.register(["n", "<page-down>"], "next", mode=api.modes.IMAGE)
 @api.commands.register(name="next")
-def next_path(count: int = 1) -> None:
+def next_path(count: int = 1, keep_zoom: bool = False) -> None:
     """Select next image.
 
+    **syntax:** ``:next [--keep-zoom]``
+
+    optional arguments:
+        * ``--keep-zoom``: Keep zoom level and scroll position of the current image.
+
     **count:** multiplier
     """
     if _paths:
-        _set_index((_index + count) % len(_paths))
+        _set_index((_index + count) % len(_paths), keep_zoom=keep_zoom)
 
 
+@api.keybindings.register("<ctrl>p", "prev --keep-zoom", mode=api.modes.IMAGE)
 @api.keybindings.register(["p", "<page-up>"], "prev", mode=api.modes.IMAGE)
 @api.commands.register(name="prev")
-def prev_path(count: int = 1) -> None:
+def prev_path(count: int = 1, keep_zoom: bool = False) -> None:
     """Select previous image.
 
+    **syntax:** ``:prev [--keep-zoom]``
+
+    optional arguments:
+        * ``--keep-zoom``: Keep zoom level and scroll position of the current image.
+
     **count:** multiplier
     """
     if _paths:
-        _set_index((_index - count) % len(_paths))
+        _set_index((_index - count) % len(_paths), keep_zoom=keep_zoom)
 
 
 @api.keybindings.register(["G", "<end>"], "goto -1", mode=api.modes.IMAGE)
@@ -110,7 +122,10 @@ def exif_date_time() -> str:
     data in the statusbar. If there are any requests/ideas for more, this can
     be used as basis to work with.
     """
-    return imutils.exif.exif_date_time(current())
+    try:
+        return imutils.exif.ExifHandler(current()).exif_date_time()
+    except imutils.exif.UnsupportedExifOperation:
+        return ""
 
 
 def pathlist() -> List[str]:
@@ -204,12 +219,12 @@ class SignalHandler(QObject):
             api.status.update("Image filelist changed")
 
 
-def _set_index(index: int, previous: str = None) -> None:
+def _set_index(index: int, previous: str = None, *, keep_zoom: bool = False) -> None:
     """Set the global _index to index."""
     global _index
     _index = index
     if previous != current():
-        api.signals.new_image_opened.emit(current())
+        api.signals.new_image_opened.emit(current(), keep_zoom)
 
 
 def _set_paths(paths: List[str]) -> None:
@@ -223,6 +238,8 @@ def _load_single(path: str) -> None:
     """Populate list of paths in same directory for single path."""
     if path in _paths:
         goto(_paths.index(path) + 1)  # goto is indexed from 1
+    elif path not in api.working_directory.handler.images and files.is_image(path):
+        _load_paths([path, *api.working_directory.handler.images], path)
     else:
         _load_paths(api.working_directory.handler.images, path)
 
