@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Main function and startup utilities for vimiv.
@@ -27,7 +27,11 @@ from vimiv.gui import mainwindow
 from vimiv.utils import xdg, crash_handler, log, trash_manager, customtypes, migration
 
 # Must be imported to create the commands using the decorators
-from vimiv.commands import misccommands, help_command  # pylint: disable=unused-import
+from vimiv.commands import (  # pylint: disable=unused-import
+    misccommands,
+    delete_command,
+    help_command,
+)
 from vimiv.config import configcommands  # pylint: disable=unused-import
 
 
