@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Various utility functions."""
@@ -50,6 +50,18 @@ def wrap_style_span(style: str, text: str) -> str:
     return f"<span style='{style};'>{text}</span>"
 
 
+def format_html_table(content: typing.Iterable[typing.Sequence[str]]) -> str:
+    """Format a nice html table for content."""
+
+    def format_row(first: str, *other: str) -> str:
+        other_elems = "".join(
+            f"<td style='padding-left: 2ex'>{elem}</td>" for elem in other
+        )
+        return f"<tr><td>{first}</td>{other_elems}</tr>"
+
+    return add_html("\n".join(format_row(*cells) for cells in content), "table")
+
+
 def strip_html(text: str) -> str:
     """Strip all html tags from text.
 
@@ -116,6 +128,15 @@ def clamp(
     return value
 
 
+def is_hex(text: str) -> bool:
+    """Return True if text is a hexadecimal digit."""
+    try:
+        int(text, base=16)
+        return True
+    except ValueError:
+        return False
+
+
 def parameter_names(function: typing.Callable) -> typing.Tuple[str, ...]:
     """Fast implementation of getting the parameter names of a function.
 
@@ -324,42 +345,42 @@ def remove_prefix(text: str, prefix: str) -> str:
     return text
 
 
-def escape_ws(text: str, whitespace: str = " ", escape_char: str = "\\\\") -> str:
-    r"""Escape whitespace in a given string.
+def escape_chars(text: str, chars: str, escape_char: str = r"\\") -> str:
+    r"""Escape set of characters in a given string.
 
     Example:
-        >>> escape_ws("some spaced text")
+        >>> escape_chars("some spaced text", " ")
         some\\ spaced\\ text
 
     Args:
         text: The text to escape whitespace in.
-        whitespace: All characters that are treated as whitespace.
+        chars: All characters that are escaped.
         escape_char: The character prepended to whitespace for escaping.
     Returns:
-        Text with the whitespace escaped.
+        Text with the characters escaped.
     """
-    # First part matches all whitespace characters that are not prepended by escape_char
-    # Second part replaces with the escape_char and the whitespace character
-    return re.sub(rf"(?<!{escape_char})([{whitespace}])", rf"{escape_char}\1", text)
+    # First part matches all chars
+    # Second part replaces with the escape_char and the matched char
+    return re.sub(rf"([{chars}])", rf"{escape_char}\1", text)
 
 
-def unescape_ws(text: str, whitespace: str = " ", escape_char: str = "\\\\") -> str:
+def unescape_chars(text: str, chars: str, escape_char: str = r"\\") -> str:
     r"""Undo escaping of whitespace in a given string.
 
     Example:
-        >>> unescape_ws("some\\ spaced\\ text")
+        >>> unescape_chars("some\\ spaced\\ text")
         some spaced text
 
     Args:
         text: The text to undo escaping of whitespace in.
-        whitespace: All characters that are treated as whitespace.
+        chars: All characters that are escaped.
         escape_char: The character prepended to whitespace for escaping.
     Returns:
-        Text with the whitespace escaping undone.
+        Text with the character escaping undone.
     """
-    # First part matches all whitespace characters that are prepended by escape_char
-    # Second part replaces with the whitespace character
-    return re.sub(rf"{escape_char}([{whitespace}])", r"\1", text)
+    # First part matches all chars that are prepended by escape_char
+    # Second part replaces with the matched char
+    return re.sub(rf"{escape_char}([{chars}])", r"\1", text)
 
 
 def create_pixmap(
