@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Handler for uncaught exceptions and signals."""
@@ -23,7 +23,7 @@ from vimiv.utils import log, customtypes
 try:
     import fcntl
 except ImportError:
-    # Mypy does not approve that we assigne None to a module but that is exactly what we
+    # Mypy does not approve that we assign None to a module but that is exactly what we
     # want to do for the optional import
     fcntl = None  # type: ignore
 
@@ -118,7 +118,6 @@ class CrashHandler(QObject):
 
         Args:
             signum: Signal number of the interrupt signal retrieved.
-            _frame: Current stack frame.
         """
         _logger.debug("Interrupt handler called with signal %d", signum)
         _assign_interrupt_handler(self.handle_interrupt_forcefully)
@@ -133,7 +132,6 @@ class CrashHandler(QObject):
 
         Args:
             signum: Signal number of the interrupt signal retrieved.
-            _frame: Current stack frame.
         """
         _logger.debug("Interrupt handler called a second time with %d", signum)
         log.fatal("Forceful kill signal retrieved... Hello darkness my old friend")
