@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Various utility functions for debugging and profiling."""
@@ -34,7 +34,7 @@ def timed(function: FuncT) -> FuncT:
 
 @contextlib.contextmanager
 def profile(amount: int = 15) -> Iterator[None]:
-    """Contextmanager to profile code secions.
+    """Contextmanager to profile code sections.
 
     Starts a cProfile.Profile upon entry, disables it on exit and prints profiling
     information.
