@@ -1,7 +1,7 @@
 # vim: ft=python fileencoding=utf-8 sw=4 et sts=4
 
 # This file is part of vimiv.
-# Copyright 2017-2020 Christian Karl (karlch) <karlch at protonmail dot com>
+# Copyright 2017-2021 Christian Karl (karlch) <karlch at protonmail dot com>
 # License: GNU GPL v3, see the "LICENSE" and "AUTHORS" files for details.
 
 """Functions dealing with files and paths."""
@@ -13,6 +13,8 @@ from typing import List, Tuple, Optional, BinaryIO, Iterable, Callable
 
 from PyQt5.QtGui import QImageReader
 
+from vimiv.utils import imagereader
+
 
 def listdir(directory: str, show_hidden: bool = False) -> List[str]:
     """Wrapper around os.listdir.
@@ -150,7 +152,10 @@ def add_image_format(name: str, check: Callable[[bytes, BinaryIO], bool]) -> Non
         if check(h, f):
             if hasattr(test, "checked"):
                 return name
-            if name in QImageReader.supportedImageFormats():
+            if (
+                name in QImageReader.supportedImageFormats()
+                or name in imagereader.external_handler
+            ):
                 setattr(test, "checked", True)
                 return name
             imghdr.tests.remove(test)
@@ -164,7 +169,7 @@ add_image_format.index = 3  # type: ignore  # Start inserting after jpg, png and
 
 
 def test_svg(h: bytes, _f: BinaryIO) -> bool:
-    return b"<?xml" in h
+    return h.startswith((b"<?xml", b"<svg"))
 
 
 add_image_format("svg", test_svg)
@@ -172,7 +177,7 @@ add_image_format("svg", test_svg)
 
 # We now directly override the jpg part of imghdr as it has some known limitations
 # See e.g. https://bugs.python.org/issue16512
-def test_jpg(h: bytes, _f: BinaryIO) -> Optional[str]:
+def test_jpg(h: bytes, _f: Optional[BinaryIO]) -> Optional[str]:
     """Custom jpg test function.
 
     The one from the imghdr module fails with some jpgs that include ICC_PROFILE data.
@@ -184,7 +189,7 @@ def test_jpg(h: bytes, _f: BinaryIO) -> Optional[str]:
     return None
 
 
-def test_jpg_fallback(h: bytes, _f: BinaryIO) -> Optional[str]:
+def test_jpg_fallback(h: bytes, _f: Optional[BinaryIO]) -> Optional[str]:
     """Fallback test for jpg files with no headers, only the two starting bits."""
     return "jpg" if h[:2] == b"\xff\xd8" else None
 
